#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
const parser_1 = __importDefault(require("../lib/parser"));
let version = '';
try {
    const pkg = fs_1.default.readFileSync(path_1.default.resolve(__dirname, '../../package.json'), 'utf8');
    let pkgJSON;
    if (pkg)
        pkgJSON = JSON.parse(pkg);
    if (pkgJSON && pkgJSON.version && typeof pkgJSON.version === 'string')
        version = pkgJSON.version;
}
catch (err) {
    abort('Failed to read package.json for version information. Try reinstalling from npm');
    throw err;
}
commander_1.program
    .arguments('<reascripthelp.html>')
    .version(version)
    .description("Parse given reascripthelp.html file and generate json file in it's directory. reascripthelp.html can be created from Reaper -> Help -> Reascript Documentation")
    .action((htmlPath) => {
    const filePath = path_1.default.resolve(process.cwd(), htmlPath);
    if (!fs_1.default.existsSync(filePath))
        abort(`${filePath} doesn't seem to exist`);
    if (!fs_1.default.lstatSync(filePath).isFile()) {
        abort(`${filePath} doesn't seem to be a file. Please point to a Reaper generated reascripthelp.html`);
    }
    if (path_1.default.extname(filePath).toLowerCase() !== '.html') {
        abort(`${filePath} is not an html file`);
    }
    let apiHTML = '';
    try {
        apiHTML = fs_1.default.readFileSync(filePath, 'utf8');
        if (!apiHTML)
            abort(`${filePath} seems to be empty`);
    }
    catch (err) {
        abort(`Failed to read ${filePath}`);
    }
    let apiJSON;
    try {
        apiJSON = parser_1.default(apiHTML);
    }
    catch (err) {
        if (err.message)
            abort(err.message);
    }
    const outputDir = path_1.default.dirname(filePath);
    const filename = 'reascript_lua_API.json';
    const outputPath = path_1.default.resolve(outputDir, filename);
    try {
        fs_1.default.writeFileSync(outputPath, JSON.stringify(apiJSON));
        console.log(`SUCCESS: ${filename} written to ${outputPath}`);
    }
    catch (err) {
        abort(`failed to write ouput to ${outputPath}. Do you have write permission on the directory?`);
    }
});
commander_1.program.parse(process.argv);
function abort(msg) {
    console.error(`ERROR: ${msg}`);
    console.error(`run with --help option for more information`);
    process.exit(1);
}
//# sourceMappingURL=cli.js.map